@@ -14,8 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+import re
 from lettuce.core import STEP_REGISTRY
+from lettuce.exceptions import StepLoadingError
 
 def step(regex):
     """Decorates a function, so that it will become a new step
@@ -35,6 +36,13 @@ def step(regex):
     Notice that all step definitions take a step object as argument.
     """
     def wrap(func):
+        try:
+            re.compile(regex)
+        except re.error, e:
+            raise StepLoadingError("Error when trying to compile:\n"
+                                   "  regex: %r\n"
+                                   "  for function: %s\n"
+                                   "  error: %s" % (regex, func, e))
         STEP_REGISTRY[regex] = func
 
     return wrap
